scxpand.mlp.mlp\_model
======================

.. automodule:: scxpand.mlp.mlp_model

   
   .. rubric:: Functions

   .. autosummary::
   
      load_nn_model
   
   .. rubric:: Classes

   .. autosummary::
   
      CategoricalHead
      FC_Net
      MLPModel
      ModelOutput
   